@@ -263,7 +263,7 @@ class TestTranslateClientModel(LiveServerTestCase):
 
         assert client.snake_key(language, "admin_dossier_downloading")
 
-    def test_get_bootstrap_keys(self):
+    def test_get_translation_keys(self):
         """Test JSON response for provided language and view."""
         from melon_translate_client import Client
 
@@ -274,7 +274,7 @@ class TestTranslateClientModel(LiveServerTestCase):
 
         _ = client.filter(language, views=[view])
 
-        keys = client.get_bootstrap_keys(language, view)
+        keys = client.get_translation_keys(language, view)
 
         assert keys
         assert len(keys) == 4
